@@ -1,5 +1,4 @@
-km<-function(s,d,c,var = c("O","G"),conf=.95){
-r<- s-d-c
+km<-function(r,d,var = "O",conf=.95,ylab="Pr(survivorship from 1st age class)",age.seq=seq(1,length(r)),xlab="Age class", ...){
 step <- (1-(d/r))## Eq.1
 s.hat<-matrix(nrow=length(r),ncol=1)
 for(i in 1:length(r)){
@@ -7,7 +6,7 @@ s.hat[1]<-step[1]*step[2]
 s.hat[i+1]<-s.hat[i]*step[i+1]}
 s.hat<-s.hat[-(length(r)+1)]
 Green.Sum<-matrix(nrow=length(r),ncol=1)
-Green.Var<-matrix(nrow=length(r),ncol=1)##Green(1926)
+Green.Var<-matrix(nrow=length(r),ncol=1)##Greenwood(1926)
 for(i in 1: length(r)){
 Green.Var[1]<-0
 Green.Sum[1]<-d[1]/(r[1]*(r[1]-d[1]))
@@ -22,14 +21,14 @@ C.U<-s.hat+ qnorm(1-((1-conf)/2))*((Oakes.Var)^.5)}
 if(var=="G"){
 C.L<-s.hat- qnorm(1-((1-conf)/2))*((Green.Var)^.5)
 C.U<-s.hat+ qnorm(1-((1-conf)/2))*((Green.Var)^.5)}
-plot(seq(1,length(r)),s.hat,ylab="Probability of survivorship from 1st age class",xlab="Age class")
-lines(seq(1,length(r)),C.L,lty=2)
-lines(seq(1,length(r)),C.U,lty=2)
+plot(age.seq,s.hat,type="b",xlab=xlab,ylab=ylab,...)
+lines(age.seq,C.L,lty=2)
+lines(age.seq,C.U,lty=2)
 res<-list()
 res$s.hat<-s.hat
 res$Greenwood.Var<-Green.Var
 res$Oakes.Var<-Oakes.Var
-res$CI<-cbind(C.L,C.U)
+res$CI<-cbind(C.L,C.U) 
 res
 }
 
